/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_IPV6_6RD_CONFIGURATION 173
#define PW_IPV6_6RD_IPV4MASKLEN 173.1
#define PW_IPV6_6RD_PREFIX 173.2
#define PW_IPV6_6RD_BR_IPV4_ADDRESS 173.3

