/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_TUNNEL_TYPE 64
#define PW_TUNNEL_MEDIUM_TYPE 65
#define PW_TUNNEL_CLIENT_ENDPOINT 66
#define PW_TUNNEL_SERVER_ENDPOINT 67
#define PW_TUNNEL_PASSWORD 69
#define PW_TUNNEL_PRIVATE_GROUP_ID 81
#define PW_TUNNEL_ASSIGNMENT_ID 82
#define PW_TUNNEL_PREFERENCE 83
#define PW_TUNNEL_CLIENT_AUTH_ID 90
#define PW_TUNNEL_SERVER_AUTH_ID 91

#define PW_TUNNEL_TYPE_PPTP 1
#define PW_TUNNEL_TYPE_L2F 2
#define PW_TUNNEL_TYPE_L2TP 3
#define PW_TUNNEL_TYPE_ATMP 4
#define PW_TUNNEL_TYPE_VTP 5
#define PW_TUNNEL_TYPE_AH 6
#define PW_TUNNEL_TYPE_IP 7
#define PW_TUNNEL_TYPE_MIN_IP 8
#define PW_TUNNEL_TYPE_ESP 9
#define PW_TUNNEL_TYPE_GRE 10
#define PW_TUNNEL_TYPE_DVS 11
#define PW_TUNNEL_TYPE_IP_IN_IP 12
#define PW_TUNNEL_MEDIUM_TYPE_IP 1
#define PW_TUNNEL_MEDIUM_TYPE_IPV4 1
#define PW_TUNNEL_MEDIUM_TYPE_IPV6 2
#define PW_TUNNEL_MEDIUM_TYPE_NSAP 3
#define PW_TUNNEL_MEDIUM_TYPE_HDLC 4
#define PW_TUNNEL_MEDIUM_TYPE_BBN_1822 5
#define PW_TUNNEL_MEDIUM_TYPE_IEEE_802 6
#define PW_TUNNEL_MEDIUM_TYPE_E_163 7
#define PW_TUNNEL_MEDIUM_TYPE_E_164 8
#define PW_TUNNEL_MEDIUM_TYPE_F_69 9
#define PW_TUNNEL_MEDIUM_TYPE_X_121 10
#define PW_TUNNEL_MEDIUM_TYPE_IPX 11
#define PW_TUNNEL_MEDIUM_TYPE_APPLETALK 12
#define PW_TUNNEL_MEDIUM_TYPE_DECNET_IV 13
#define PW_TUNNEL_MEDIUM_TYPE_BANYAN_VINES 14
#define PW_TUNNEL_MEDIUM_TYPE_E_164_NSAP 15
