/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_ACCT_STATUS_TYPE 40
#define PW_ACCT_DELAY_TIME 41
#define PW_ACCT_INPUT_OCTETS 42
#define PW_ACCT_OUTPUT_OCTETS 43
#define PW_ACCT_SESSION_ID 44
#define PW_ACCT_AUTHENTIC 45
#define PW_ACCT_SESSION_TIME 46
#define PW_ACCT_INPUT_PACKETS 47
#define PW_ACCT_OUTPUT_PACKETS 48
#define PW_ACCT_TERMINATE_CAUSE 49
#define PW_ACCT_MULTI_SESSION_ID 50
#define PW_ACCT_LINK_COUNT 51

#define PW_ACCT_STATUS_TYPE_START 1
#define PW_ACCT_STATUS_TYPE_STOP 2
#define PW_ACCT_STATUS_TYPE_ALIVE 3
#define PW_ACCT_STATUS_TYPE_INTERIM_UPDATE 3
#define PW_ACCT_STATUS_TYPE_ACCOUNTING_ON 7
#define PW_ACCT_STATUS_TYPE_ACCOUNTING_OFF 8
#define PW_ACCT_STATUS_TYPE_FAILED 15
#define PW_ACCT_AUTHENTIC_RADIUS 1
#define PW_ACCT_AUTHENTIC_LOCAL 2
#define PW_ACCT_AUTHENTIC_REMOTE 3
#define PW_ACCT_AUTHENTIC_DIAMETER 4
#define PW_ACCT_TERMINATE_CAUSE_USER_REQUEST 1
#define PW_ACCT_TERMINATE_CAUSE_LOST_CARRIER 2
#define PW_ACCT_TERMINATE_CAUSE_LOST_SERVICE 3
#define PW_ACCT_TERMINATE_CAUSE_IDLE_TIMEOUT 4
#define PW_ACCT_TERMINATE_CAUSE_SESSION_TIMEOUT 5
#define PW_ACCT_TERMINATE_CAUSE_ADMIN_RESET 6
#define PW_ACCT_TERMINATE_CAUSE_ADMIN_REBOOT 7
#define PW_ACCT_TERMINATE_CAUSE_PORT_ERROR 8
#define PW_ACCT_TERMINATE_CAUSE_NAS_ERROR 9
#define PW_ACCT_TERMINATE_CAUSE_NAS_REQUEST 10
#define PW_ACCT_TERMINATE_CAUSE_NAS_REBOOT 11
#define PW_ACCT_TERMINATE_CAUSE_PORT_UNNEEDED 12
#define PW_ACCT_TERMINATE_CAUSE_PORT_PREEMPTED 13
#define PW_ACCT_TERMINATE_CAUSE_PORT_SUSPENDED 14
#define PW_ACCT_TERMINATE_CAUSE_SERVICE_UNAVAILABLE 15
#define PW_ACCT_TERMINATE_CAUSE_CALLBACK 16
#define PW_ACCT_TERMINATE_CAUSE_USER_ERROR 17
#define PW_ACCT_TERMINATE_CAUSE_HOST_REQUEST 18
