/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */

#define PW_NAS_PORT_TYPE_PPPOA 30
#define PW_NAS_PORT_TYPE_PPPOEOA 31
#define PW_NAS_PORT_TYPE_PPPOEOE 32
#define PW_NAS_PORT_TYPE_PPPOEOVLAN 33
#define PW_NAS_PORT_TYPE_PPPOEOQINQ 34
