/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_OPERATOR_NAME 126
#define PW_LOCATION_INFORMATION 127
#define PW_LOCATION_DATA 128
#define PW_BASIC_LOCATION_POLICY_RULES 129
#define PW_EXTENDED_LOCATION_POLICY_RULES 130
#define PW_LOCATION_CAPABLE 131
#define PW_REQUESTED_LOCATION_INFO 132

#define PW_LOCATION_CAPABLE_CIVIC_LOCATION 1
#define PW_LOCATION_CAPABLE_GEO_LOCATION 2
#define PW_LOCATION_CAPABLE_USERS_LOCATION 4
#define PW_LOCATION_CAPABLE_NAS_LOCATION 8
#define PW_REQUESTED_LOCATION_INFO_CIVIC_LOCATION 1
#define PW_REQUESTED_LOCATION_INFO_GEO_LOCATION 2
#define PW_REQUESTED_LOCATION_INFO_USERS_LOCATION 4
#define PW_REQUESTED_LOCATION_INFO_NAS_LOCATION 8
#define PW_REQUESTED_LOCATION_INFO_FUTURE_REQUESTS 16
#define PW_REQUESTED_LOCATION_INFO_NONE 32
#define PW_ERROR_CAUSE_LOCATION_INFO_REQUIRED 509
