/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */

#define PW_ACCT_TERMINATE_CAUSE_SUPPLICANT_RESTART 19
#define PW_ACCT_TERMINATE_CAUSE_REAUTHENTICATION_FAILURE 20
#define PW_ACCT_TERMINATE_CAUSE_PORT_REINIT 21
#define PW_ACCT_TERMINATE_CAUSE_PORT_DISABLED 22
#define PW_NAS_PORT_TYPE_TOKEN_RING 20
#define PW_NAS_PORT_TYPE_FDDI 21
#define PW_TUNNEL_TYPE_VLAN 13
