/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_FREERADIUS_PROXIED_TO 1
#define PW_FREERADIUS_ACCT_SESSION_START_TIME 2
#define PW_FREERADIUS_STATISTICS_TYPE 127
#define PW_FREERADIUS_TOTAL_ACCESS_REQUESTS 128
#define PW_FREERADIUS_TOTAL_ACCESS_ACCEPTS 129
#define PW_FREERADIUS_TOTAL_ACCESS_REJECTS 130
#define PW_FREERADIUS_TOTAL_ACCESS_CHALLENGES 131
#define PW_FREERADIUS_TOTAL_AUTH_RESPONSES 132
#define PW_FREERADIUS_TOTAL_AUTH_DUPLICATE_REQUESTS 133
#define PW_FREERADIUS_TOTAL_AUTH_MALFORMED_REQUESTS 134
#define PW_FREERADIUS_TOTAL_AUTH_INVALID_REQUESTS 135
#define PW_FREERADIUS_TOTAL_AUTH_DROPPED_REQUESTS 136
#define PW_FREERADIUS_TOTAL_AUTH_UNKNOWN_TYPES 137
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_REQUESTS 138
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_ACCEPTS 139
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_REJECTS 140
#define PW_FREERADIUS_TOTAL_PROXY_ACCESS_CHALLENGES 141
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_RESPONSES 142
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_DUPLICATE_REQUESTS 143
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_MALFORMED_REQUESTS 144
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_INVALID_REQUESTS 145
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_DROPPED_REQUESTS 146
#define PW_FREERADIUS_TOTAL_PROXY_AUTH_UNKNOWN_TYPES 147
#define PW_FREERADIUS_TOTAL_ACCOUNTING_REQUESTS 148
#define PW_FREERADIUS_TOTAL_ACCOUNTING_RESPONSES 149
#define PW_FREERADIUS_TOTAL_ACCT_DUPLICATE_REQUESTS 150
#define PW_FREERADIUS_TOTAL_ACCT_MALFORMED_REQUESTS 151
#define PW_FREERADIUS_TOTAL_ACCT_INVALID_REQUESTS 152
#define PW_FREERADIUS_TOTAL_ACCT_DROPPED_REQUESTS 153
#define PW_FREERADIUS_TOTAL_ACCT_UNKNOWN_TYPES 154
#define PW_FREERADIUS_TOTAL_PROXY_ACCOUNTING_REQUESTS 155
#define PW_FREERADIUS_TOTAL_PROXY_ACCOUNTING_RESPONSES 156
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_DUPLICATE_REQUESTS 157
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_MALFORMED_REQUESTS 158
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_INVALID_REQUESTS 159
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_DROPPED_REQUESTS 160
#define PW_FREERADIUS_TOTAL_PROXY_ACCT_UNKNOWN_TYPES 161
#define PW_FREERADIUS_QUEUE_LEN_INTERNAL 162
#define PW_FREERADIUS_QUEUE_LEN_PROXY 163
#define PW_FREERADIUS_QUEUE_LEN_AUTH 164
#define PW_FREERADIUS_QUEUE_LEN_ACCT 165
#define PW_FREERADIUS_QUEUE_LEN_DETAIL 166
#define PW_FREERADIUS_STATS_CLIENT_IP_ADDRESS 167
#define PW_FREERADIUS_STATS_CLIENT_NUMBER 168
#define PW_FREERADIUS_STATS_CLIENT_NETMASK 169
#define PW_FREERADIUS_STATS_SERVER_IP_ADDRESS 170
#define PW_FREERADIUS_STATS_SERVER_PORT 171
#define PW_FREERADIUS_STATS_SERVER_OUTSTANDING_REQUESTS 172
#define PW_FREERADIUS_STATS_SERVER_STATE 173
#define PW_FREERADIUS_STATS_SERVER_TIME_OF_DEATH 174
#define PW_FREERADIUS_STATS_SERVER_TIME_OF_LIFE 175
#define PW_FREERADIUS_STATS_START_TIME 176
#define PW_FREERADIUS_STATS_HUP_TIME 177
#define PW_FREERADIUS_SERVER_EMA_WINDOW 178
#define PW_FREERADIUS_SERVER_EMA_USEC_WINDOW_1 179
#define PW_FREERADIUS_SERVER_EMA_USEC_WINDOW_10 180
#define PW_FREERADIUS_QUEUE_PPS_IN 181
#define PW_FREERADIUS_QUEUE_PPS_OUT 182
#define PW_FREERADIUS_QUEUE_USE_PERCENTAGE 183
#define PW_FREERADIUS_STATS_LAST_PACKET_RECV 184
#define PW_FREERADIUS_STATS_LAST_PACKET_SENT 185
#define PW_FREERADIUS_EAP_FAST_TLV 186
#define PW_FREERADIUS_EAP_FAST_RESULT 186.3
#define PW_FREERADIUS_EAP_FAST_NAK 186.4
#define PW_FREERADIUS_EAP_FAST_ERROR 186.5
#define PW_FREERADIUS_EAP_FAST_VENDOR_SPECIFIC 186.7
#define PW_FREERADIUS_EAP_FAST_EAP_PAYLOAD 186.9
#define PW_FREERADIUS_EAP_FAST_INTERMEDIATE_RESULT 186.10
#define PW_FREERADIUS_EAP_FAST_PAC 186.11
#define PW_FREERADIUS_EAP_FAST_PAC_KEY 186.11.1
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_TLV 186.11.2
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_PAC_KEY 186.11.2.1
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_PAC_LIFETIME 186.11.2.3
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_I_ID 186.11.2.5
#define PW_FREERADIUS_EAP_FAST_PAC_OPAQUE_PAC_TYPE 186.11.2.10
#define PW_FREERADIUS_EAP_FAST_PAC_LIFETIME 186.11.3
#define PW_FREERADIUS_EAP_FAST_PAC_A_ID 186.11.4
#define PW_FREERADIUS_EAP_FAST_PAC_I_ID 186.11.5
#define PW_FREERADIUS_EAP_FAST_PAC_A_ID_INFO 186.11.7
#define PW_FREERADIUS_EAP_FAST_PAC_ACKNOWLEDGE 186.11.8
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_TLV 186.11.9
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_PAC_LIFETIME 186.11.9.3
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_A_ID 186.11.9.4
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_I_ID 186.11.9.5
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_A_ID_INFO 186.11.9.7
#define PW_FREERADIUS_EAP_FAST_PAC_INFO_PAC_TYPE 186.11.9.10
#define PW_FREERADIUS_EAP_FAST_PAC_TYPE 186.11.10
#define PW_FREERADIUS_EAP_FAST_CRYPTO_BINDING 186.12
#define PW_FREERADIUS_EAP_FAST_TRUSTED_ROOT 186.18
#define PW_FREERADIUS_EAP_FAST_REQUEST_ACTION 186.19
#define PW_FREERADIUS_EAP_FAST_PKCS 186.20
#define PW_FREERADIUS_STATS_ERROR 187
#define PW_FREERADIUS_STATS_CLIENT_IPV6_ADDRESS 188
#define PW_FREERADIUS_STATS_SERVER_IPV6_ADDRESS 189
#define PW_FREERADIUS_EAP_TEAP_TLV 190
#define PW_FREERADIUS_EAP_TEAP_AUTHORITY_ID 190.1
#define PW_FREERADIUS_EAP_TEAP_IDENTITY_TYPE 190.2
#define PW_FREERADIUS_EAP_TEAP_RESULT 190.3
#define PW_FREERADIUS_EAP_TEAP_NAK 190.4
#define PW_FREERADIUS_EAP_TEAP_ERROR 190.5
#define PW_FREERADIUS_EAP_TEAP_CHANNEL_BINDING 190.6
#define PW_FREERADIUS_EAP_TEAP_VENDOR_SPECIFIC 190.7
#define PW_FREERADIUS_EAP_TEAP_REQUEST_ACTION 190.8
#define PW_FREERADIUS_EAP_TEAP_EAP_PAYLOAD 190.9
#define PW_FREERADIUS_EAP_TEAP_INTERMEDIATE_RESULT 190.10
#define PW_FREERADIUS_EAP_TEAP_PAC 190.11
#define PW_FREERADIUS_EAP_TEAP_PAC_KEY 190.11.1
#define PW_FREERADIUS_EAP_TEAP_PAC_OPAQUE 190.11.2
#define PW_FREERADIUS_EAP_TEAP_PAC_LIFETIME 190.11.3
#define PW_FREERADIUS_EAP_TEAP_PAC_A_ID 190.11.4
#define PW_FREERADIUS_EAP_TEAP_PAC_I_ID 190.11.5
#define PW_FREERADIUS_EAP_TEAP_PAC_A_ID_INFO 190.11.7
#define PW_FREERADIUS_EAP_TEAP_PAC_ACKNOWLEDGEMENT 190.11.8
#define PW_FREERADIUS_EAP_TEAP_PAC_INFO_TLV 190.11.9
#define PW_FREERADIUS_EAP_TRAP_PAC_TYPE 186.11.10
#define PW_FREERADIUS_EAP_TEAP_PAC_INFO_PAC_LIFETIME 190.11.9.3
#define PW_FREERADIUS_EAP_TEAP_PAC_INFO_A_ID 190.11.9.4
#define PW_FREERADIUS_EAP_TEAP_PAC_INFO_I_ID 190.11.9.5
#define PW_FREERADIUS_EAP_TEAP_PAC_INFO_A_ID_INFO 190.11.9.7
#define PW_FREERADIUS_EAP_TEAP_PAC_INFO_PAC_TYPE 190.11.9.10
#define PW_FREERADIUS_EAP_TEAP_PAC_TYPE 190.11.10
#define PW_FREERADIUS_EAP_TEAP_CRYPTO_BINDING 190.12
#define PW_FREERADIUS_EAP_TEAP_BASIC_PASSWORD_AUTH_REQ 190.13
#define PW_FREERADIUS_EAP_TEAP_BASIC_PASSWORD_AUTH_RESP 190.14
#define PW_FREERADIUS_EAP_TEAP_PKCS7 190.15
#define PW_FREERADIUS_EAP_TEAP_PKCS10 190.16
#define PW_FREERADIUS_EAP_TEAP_TRUSTED_SERVER_ROOT 190.17
#define PW_FREERADIUS_TOTAL_AUTH_CONFLICTS 191
#define PW_FREERADIUS_TOTAL_ACCT_CONFLICTS 192
#define PW_FREERADIUS_STATS_THREADS_ACTIVE 193
#define PW_FREERADIUS_STATS_THREADS_TOTAL 194
#define PW_FREERADIUS_STATS_THREADS_MAX 195
#define PW_FREERADIUS_STATS_SERVER_SRC_IP_ADDRESS 196
#define PW_FREERADIUS_STATS_SERVER_SRC_IPV6_ADDRESS 197
#define PW_FREERADIUS_STATS_ELAPSED 198
#define PW_FREERADIUS_STATS_ELAPSED_1US 198.1
#define PW_FREERADIUS_STATS_ELAPSED_10US 198.2
#define PW_FREERADIUS_STATS_ELAPSED_100US 198.3
#define PW_FREERADIUS_STATS_ELAPSED_1MS 198.4
#define PW_FREERADIUS_STATS_ELAPSED_10MS 198.5
#define PW_FREERADIUS_STATS_ELAPSED_100MS 198.6
#define PW_FREERADIUS_STATS_ELAPSED_1S 198.7
#define PW_FREERADIUS_STATS_ELAPSED_10S 198.8

#define PW_FREERADIUS_STATISTICS_TYPE_NONE 0
#define PW_FREERADIUS_STATISTICS_TYPE_AUTHENTICATION 1
#define PW_FREERADIUS_STATISTICS_TYPE_ACCOUNTING 2
#define PW_FREERADIUS_STATISTICS_TYPE_PROXY_AUTHENTICATION 4
#define PW_FREERADIUS_STATISTICS_TYPE_PROXY_ACCOUNTING 8
#define PW_FREERADIUS_STATISTICS_TYPE_INTERNAL 0X10
#define PW_FREERADIUS_STATISTICS_TYPE_CLIENT 0X20
#define PW_FREERADIUS_STATISTICS_TYPE_SERVER 0X40
#define PW_FREERADIUS_STATISTICS_TYPE_HOME_SERVER 0X80
#define PW_FREERADIUS_STATISTICS_TYPE_AUTH_ACCT 0X03
#define PW_FREERADIUS_STATISTICS_TYPE_PROXY_AUTH_ACCT 0X0C
#define PW_FREERADIUS_STATISTICS_TYPE_ALL 0X1F
#define PW_FREERADIUS_STATS_SERVER_STATE_ALIVE 0
#define PW_FREERADIUS_STATS_SERVER_STATE_ZOMBIE 1
#define PW_FREERADIUS_STATS_SERVER_STATE_DEAD 2
#define PW_FREERADIUS_STATS_SERVER_STATE_IDLE 3
#define PW_FREERADIUS_STATS_SERVER_STATE_ADMIN_DOWN 4
#define PW_FREERADIUS_STATS_SERVER_STATE_CONNECTION_FAIL 5
#define PW_FREERADIUS_EAP_TEAP_IDENTITY_TYPE_USER 1
#define PW_FREERADIUS_EAP_TEAP_IDENTITY_TYPE_MACHINE 2
#define PW_FREERADIUS_EAP_TEAP_RESULT_SUCCESS 1
#define PW_FREERADIUS_EAP_TEAP_RESULT_FAILURE 2
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_EXPIRES_SOON 1
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_CREDENTIAL_EXPIRES_SOON 2
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_AUTHORIZATIONS_CHANGE_SOON 3
#define PW_FREERADIUS_EAP_TEAP_ERROR_CLOCK_SKEW_DETECTED 4
#define PW_FREERADIUS_EAP_TEAP_ERROR_CONTACT_ADMINISTRATOR 5
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_CREDENTIALS_CHANGE_REQUIRES 6
#define PW_FREERADIUS_EAP_TEAP_ERROR_INNER_METHOD_ERROR 1001
#define PW_FREERADIUS_EAP_TEAP_ERROR_UNSPECIFIED_AUTHENTICATION_INFRASTRUCTURE_PROBLEM 1002
#define PW_FREERADIUS_EAP_TEAP_ERROR_UNSPECIFIED_AUTHENTICATION_FAILURE 1003
#define PW_FREERADIUS_EAP_TEAP_ERROR_UNSPECIFIED_AUTHORIZATION_FAILURE 1004
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_CREDENTIALS_UNAVAILABLE 1005
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_EXPIRED 1006
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_LOCKED_TRY_AGAIN_LATER 1007
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_LOCKED_ADMIN_INTERVENTION_REQUIRED 1008
#define PW_FREERADIUS_EAP_TEAP_ERROR_AUTHENTICATION_INFRASTRUCTURE_UNAVAILABLE 1009
#define PW_FREERADIUS_EAP_TEAP_ERROR_AUTHENTICATION_INFRASTRUCTURE_NOT_TRUSTED 1010
#define PW_FREERADIUS_EAP_TEAP_ERROR_CLOCK_SKEW_TOO_GREAT 1011
#define PW_FREERADIUS_EAP_TEAP_ERROR_INVALID_INNER_REALM 1012
#define PW_FREERADIUS_EAP_TEAP_ERROR_TOKEN_OUT_OF_SYNC_ADMIN_INTERVENTION_REQUIRED 1013
#define PW_FREERADIUS_EAP_TEAP_ERROR_TOKEN_OUT_OF_SYNC_PIN_CHANGE_REQUIRED 1014
#define PW_FREERADIUS_EAP_TEAP_ERROR_TOKEN_REVOKED 1015
#define PW_FREERADIUS_EAP_TEAP_ERROR_TOKENS_EXHAUSTED 1016
#define PW_FREERADIUS_EAP_TEAP_ERROR_CHALLENGE_EXPIRED 1017
#define PW_FREERADIUS_EAP_TEAP_ERROR_CHALLENGE_ALGORITHM_MISMATCH 1018
#define PW_FREERADIUS_EAP_TEAP_ERROR_CLIENT_CERTIFICATE_NOT_SUPPLIED 1019
#define PW_FREERADIUS_EAP_TEAP_ERROR_CLIENT_CERTIFICATE_REJECTED 1020
#define PW_FREERADIUS_EAP_TEAP_ERROR_REALM_MISMATCH_INNER_OUTER_IDENTITY 1021
#define PW_FREERADIUS_EAP_TEAP_ERROR_UNSUPPORTED_ALGORITHM_IN_CSR 1022
#define PW_FREERADIUS_EAP_TEAP_ERROR_UNSUPPORTED_EXTENSION_IN_CSR 1023
#define PW_FREERADIUS_EAP_TEAP_ERROR_BAD_IDENTITY_IN_CSR 1024
#define PW_FREERADIUS_EAP_TEAP_ERROR_BAD_CSR 1025
#define PW_FREERADIUS_EAP_TEAP_ERROR_INTERNAL_CA_ERROR 1026
#define PW_FREERADIUS_EAP_TEAP_ERROR_GENERAL_PKI_ERROR 1027
#define PW_FREERADIUS_EAP_TEAP_ERROR_INNER_METHOD_CHANNEL_BINDING_NOT_SUPPLIED 1028
#define PW_FREERADIUS_EAP_TEAP_ERROR_INNER_METHOD_CHANNEL_BINDING_MISSING_INFO 1029
#define PW_FREERADIUS_EAP_TEAP_ERROR_INNER_METHOD_CHANNEL_BINDING_DATA_FAILED 1030
#define PW_FREERADIUS_EAP_TEAP_ERROR_USER_ACCOUNT_CREDENTIALS_INCORRECT 1031
#define PW_FREERADIUS_EAP_TEAP_ERROR_TUNNEL_COMPROMISE_ERROR 2001
#define PW_FREERADIUS_EAP_TEAP_ERROR_UNEXPECTED_TLVS 2002
#define PW_FREERADIUS_EAP_TEAP_INTERMEDIATE_RESULT_SUCCESS 1
#define PW_FREERADIUS_EAP_TEAP_INTERMEDIATE_RESULT_FAILURE 2
