/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_USER_NAME 1
#define PW_USER_PASSWORD 2
#define PW_CHAP_PASSWORD 3
#define PW_NAS_IP_ADDRESS 4
#define PW_NAS_PORT 5
#define PW_SERVICE_TYPE 6
#define PW_FRAMED_PROTOCOL 7
#define PW_FRAMED_IP_ADDRESS 8
#define PW_FRAMED_IP_NETMASK 9
#define PW_FRAMED_ROUTING 10
#define PW_FILTER_ID 11
#define PW_FRAMED_MTU 12
#define PW_FRAMED_COMPRESSION 13
#define PW_LOGIN_IP_HOST 14
#define PW_LOGIN_SERVICE 15
#define PW_LOGIN_TCP_PORT 16
#define PW_REPLY_MESSAGE 18
#define PW_CALLBACK_NUMBER 19
#define PW_CALLBACK_ID 20
#define PW_FRAMED_ROUTE 22
#define PW_FRAMED_IPX_NETWORK 23
#define PW_STATE 24
#define PW_CLASS 25
#define PW_VENDOR_SPECIFIC 26
#define PW_SESSION_TIMEOUT 27
#define PW_IDLE_TIMEOUT 28
#define PW_TERMINATION_ACTION 29
#define PW_CALLED_STATION_ID 30
#define PW_CALLING_STATION_ID 31
#define PW_NAS_IDENTIFIER 32
#define PW_PROXY_STATE 33
#define PW_LOGIN_LAT_SERVICE 34
#define PW_LOGIN_LAT_NODE 35
#define PW_LOGIN_LAT_GROUP 36
#define PW_FRAMED_APPLETALK_LINK 37
#define PW_FRAMED_APPLETALK_NETWORK 38
#define PW_FRAMED_APPLETALK_ZONE 39
#define PW_CHAP_CHALLENGE 60
#define PW_NAS_PORT_TYPE 61
#define PW_PORT_LIMIT 62
#define PW_LOGIN_LAT_PORT 63

#define PW_SERVICE_TYPE_LOGIN_USER 1
#define PW_SERVICE_TYPE_FRAMED_USER 2
#define PW_SERVICE_TYPE_CALLBACK_LOGIN_USER 3
#define PW_SERVICE_TYPE_CALLBACK_FRAMED_USER 4
#define PW_SERVICE_TYPE_OUTBOUND_USER 5
#define PW_SERVICE_TYPE_ADMINISTRATIVE_USER 6
#define PW_SERVICE_TYPE_NAS_PROMPT_USER 7
#define PW_SERVICE_TYPE_AUTHENTICATE_ONLY 8
#define PW_SERVICE_TYPE_CALLBACK_NAS_PROMPT 9
#define PW_SERVICE_TYPE_CALL_CHECK 10
#define PW_SERVICE_TYPE_CALLBACK_ADMINISTRATIVE 11
#define PW_FRAMED_PROTOCOL_PPP 1
#define PW_FRAMED_PROTOCOL_SLIP 2
#define PW_FRAMED_PROTOCOL_ARAP 3
#define PW_FRAMED_PROTOCOL_GANDALF_SLML 4
#define PW_FRAMED_PROTOCOL_XYLOGICS_IPX_SLIP 5
#define PW_FRAMED_PROTOCOL_X_75_SYNCHRONOUS 6
#define PW_FRAMED_ROUTING_NONE 0
#define PW_FRAMED_ROUTING_BROADCAST 1
#define PW_FRAMED_ROUTING_LISTEN 2
#define PW_FRAMED_ROUTING_BROADCAST_LISTEN 3
#define PW_FRAMED_COMPRESSION_NONE 0
#define PW_FRAMED_COMPRESSION_VAN_JACOBSON_TCP_IP 1
#define PW_FRAMED_COMPRESSION_IPX_HEADER_COMPRESSION 2
#define PW_FRAMED_COMPRESSION_STAC_LZS 3
#define PW_LOGIN_SERVICE_TELNET 0
#define PW_LOGIN_SERVICE_RLOGIN 1
#define PW_LOGIN_SERVICE_TCP_CLEAR 2
#define PW_LOGIN_SERVICE_PORTMASTER 3
#define PW_LOGIN_SERVICE_LAT 4
#define PW_LOGIN_SERVICE_X25_PAD 5
#define PW_LOGIN_SERVICE_X25_T3POS 6
#define PW_LOGIN_SERVICE_TCP_CLEAR_QUIET 8
#define PW_LOGIN_TCP_PORT_TELNET 23
#define PW_LOGIN_TCP_PORT_RLOGIN 513
#define PW_LOGIN_TCP_PORT_RSH 514
#define PW_TERMINATION_ACTION_DEFAULT 0
#define PW_TERMINATION_ACTION_RADIUS_REQUEST 1
#define PW_NAS_PORT_TYPE_ASYNC 0
#define PW_NAS_PORT_TYPE_SYNC 1
#define PW_NAS_PORT_TYPE_ISDN 2
#define PW_NAS_PORT_TYPE_ISDN_V120 3
#define PW_NAS_PORT_TYPE_ISDN_V110 4
#define PW_NAS_PORT_TYPE_VIRTUAL 5
#define PW_NAS_PORT_TYPE_PIAFS 6
#define PW_NAS_PORT_TYPE_HDLC_CLEAR_CHANNEL 7
#define PW_NAS_PORT_TYPE_X_25 8
#define PW_NAS_PORT_TYPE_X_75 9
#define PW_NAS_PORT_TYPE_G_3_FAX 10
#define PW_NAS_PORT_TYPE_SDSL 11
#define PW_NAS_PORT_TYPE_ADSL_CAP 12
#define PW_NAS_PORT_TYPE_ADSL_DMT 13
#define PW_NAS_PORT_TYPE_IDSL 14
#define PW_NAS_PORT_TYPE_ETHERNET 15
#define PW_NAS_PORT_TYPE_XDSL 16
#define PW_NAS_PORT_TYPE_CABLE 17
#define PW_NAS_PORT_TYPE_WIRELESS_OTHER 18
#define PW_NAS_PORT_TYPE_WIRELESS_802_11 19
