/* AUTO-GENERATED HEADER FILE.  DO NOT EDIT. */
#define PW_RESPONSE_LENGTH 241.3
#define PW_ORIGINAL_PACKET_CODE 241.4

#define PW_ORIGINAL_PACKET_CODE_ACCESS_REQUEST 1
#define PW_ORIGINAL_PACKET_CODE_ACCESS_ACCEPT 2
#define PW_ORIGINAL_PACKET_CODE_ACCESS_REJECT 3
#define PW_ORIGINAL_PACKET_CODE_ACCOUNTING_REQUEST 4
#define PW_ORIGINAL_PACKET_CODE_ACCOUNTING_RESPONSE 5
#define PW_ORIGINAL_PACKET_CODE_ACCOUNTING_STATUS 6
#define PW_ORIGINAL_PACKET_CODE_PASSWORD_REQUEST 7
#define PW_ORIGINAL_PACKET_CODE_PASSWORD_ACCEPT 8
#define PW_ORIGINAL_PACKET_CODE_PASSWORD_REJECT 9
#define PW_ORIGINAL_PACKET_CODE_ACCOUNTING_MESSAGE 10
#define PW_ORIGINAL_PACKET_CODE_ACCESS_CHALLENGE 11
#define PW_ORIGINAL_PACKET_CODE_STATUS_SERVER 12
#define PW_ORIGINAL_PACKET_CODE_STATUS_CLIENT 13
#define PW_ORIGINAL_PACKET_CODE_RESOURCE_FREE_REQUEST 21
#define PW_ORIGINAL_PACKET_CODE_RESOURCE_FREE_RESPONSE 22
#define PW_ORIGINAL_PACKET_CODE_RESOURCE_QUERY_REQUEST 23
#define PW_ORIGINAL_PACKET_CODE_RESOURCE_QUERY_RESPONSE 24
#define PW_ORIGINAL_PACKET_CODE_ALTERNATE_RESOURCE_RECLAIM_REQUEST 25
#define PW_ORIGINAL_PACKET_CODE_NAS_REBOOT_REQUEST 26
#define PW_ORIGINAL_PACKET_CODE_NAS_REBOOT_RESPONSE 27
#define PW_ORIGINAL_PACKET_CODE_NEXT_PASSCODE 29
#define PW_ORIGINAL_PACKET_CODE_NEW_PIN 30
#define PW_ORIGINAL_PACKET_CODE_TERMINATE_SESSION 31
#define PW_ORIGINAL_PACKET_CODE_PASSWORD_EXPIRED 32
#define PW_ORIGINAL_PACKET_CODE_EVENT_REQUEST 33
#define PW_ORIGINAL_PACKET_CODE_EVENT_RESPONSE 34
#define PW_ORIGINAL_PACKET_CODE_DISCONNECT_REQUEST 40
#define PW_ORIGINAL_PACKET_CODE_DISCONNECT_ACK 41
#define PW_ORIGINAL_PACKET_CODE_DISCONNECT_NAK 42
#define PW_ORIGINAL_PACKET_CODE_COA_REQUEST 43
#define PW_ORIGINAL_PACKET_CODE_COA_ACK 44
#define PW_ORIGINAL_PACKET_CODE_COA_NAK 45
#define PW_ORIGINAL_PACKET_CODE_IP_ADDRESS_ALLOCATE 50
#define PW_ORIGINAL_PACKET_CODE_IP_ADDRESS_RELEASE 51
#define PW_ORIGINAL_PACKET_CODE_PROTOCOL_ERROR 52
#define PW_ERROR_CAUSE_RESPONSE_TOO_BIG 601
